diff --git a/drivers/net/nfp/flower/nfp_flower.c b/drivers/net/nfp/flower/nfp_flower.c
index 9212e6606b..159f88f5ae 100644
--- a/drivers/net/nfp/flower/nfp_flower.c
+++ b/drivers/net/nfp/flower/nfp_flower.c
@@ -550,7 +550,7 @@ nfp_flower_pf_xmit_pkts(void *tx_queue,
 
 		if ((pkt->ol_flags & RTE_MBUF_F_TX_VLAN) &&
 				(hw->cap & NFP_NET_CFG_CTRL_TXVLAN)) {
-			txd.flags |= PCIE_DESC_TX_VLAN;
+			txd.flags |= NFD3_DESC_TX_VLAN;
 			txd.vlan = pkt->vlan_tci;
 		}
 
@@ -596,7 +596,7 @@ nfp_flower_pf_xmit_pkts(void *tx_queue,
 			 * the priority
 			 */
 			if (likely(pkt_size == 0))
-				txds->offset_eop = PCIE_DESC_TX_EOP | FLOWER_PKT_DATA_OFFSET;
+				txds->offset_eop = NFD3_DESC_TX_EOP | FLOWER_PKT_DATA_OFFSET;
 			else
 				txds->offset_eop = 0;
 
diff --git a/drivers/net/nfp/flower/nfp_flower_ctrl.c b/drivers/net/nfp/flower/nfp_flower_ctrl.c
index 7f9dc5683b..937829c23c 100644
--- a/drivers/net/nfp/flower/nfp_flower_ctrl.c
+++ b/drivers/net/nfp/flower/nfp_flower_ctrl.c
@@ -208,7 +208,7 @@ nfp_flower_ctrl_vnic_xmit(struct nfp_app_fw_flower *app_fw_flower,
 	txds->dma_len = txds->data_len;
 	txds->dma_addr_hi = (dma_addr >> 32) & 0xff;
 	txds->dma_addr_lo = (dma_addr & 0xffffffff);
-	txds->offset_eop = FLOWER_PKT_DATA_OFFSET | PCIE_DESC_TX_EOP;
+	txds->offset_eop = FLOWER_PKT_DATA_OFFSET | NFD3_DESC_TX_EOP;
 
 	txq->wr_p++;
 	if (unlikely(txq->wr_p == txq->tx_count)) /* wrapping?*/
diff --git a/drivers/net/nfp/nfd3/nfp_nfd3_dp.c b/drivers/net/nfp/nfd3/nfp_nfd3_dp.c
index 509d5b0c88..909156d69c 100644
--- a/drivers/net/nfp/nfd3/nfp_nfd3_dp.c
+++ b/drivers/net/nfp/nfd3/nfp_nfd3_dp.c
@@ -34,7 +34,7 @@ nfp_net_nfd3_tx_vlan(struct nfp_net_txq *txq,
 		return;
 
 	if ((mb->ol_flags & RTE_MBUF_F_TX_VLAN) != 0) {
-		txd->flags |= PCIE_DESC_TX_VLAN;
+		txd->flags |= NFD3_DESC_TX_VLAN;
 		txd->vlan = mb->vlan_tci;
 	}
 }
@@ -201,7 +201,7 @@ nfp_net_nfd3_xmit_pkts(void *tx_queue,
 			 * the priority
 			 */
 			if (likely(pkt_size == 0))
-				txds->offset_eop = PCIE_DESC_TX_EOP;
+				txds->offset_eop = NFD3_DESC_TX_EOP;
 			else
 				txds->offset_eop = 0;
 

diff --git a/drivers/net/nfp/nfd3/nfp_nfd3.h b/drivers/net/nfp/nfd3/nfp_nfd3.h
index 90dd376f9a..7bf2349904 100644
--- a/drivers/net/nfp/nfd3/nfp_nfd3.h
+++ b/drivers/net/nfp/nfd3/nfp_nfd3.h
@@ -7,18 +7,18 @@
 #define _NFP_NFD3_H_
 
 /* TX descriptor format */
-#define PCIE_DESC_TX_EOP                RTE_BIT32(7)
-#define PCIE_DESC_TX_OFFSET_MASK        (0x7F)        /* [0,6] */
+#define NFD3_DESC_TX_EOP                RTE_BIT32(7)
+#define NFD3_DESC_TX_OFFSET_MASK        (0x7F)        /* [0,6] */
 
 /* Flags in the host TX descriptor */
-#define PCIE_DESC_TX_CSUM               RTE_BIT32(7)
-#define PCIE_DESC_TX_IP4_CSUM           RTE_BIT32(6)
-#define PCIE_DESC_TX_TCP_CSUM           RTE_BIT32(5)
-#define PCIE_DESC_TX_UDP_CSUM           RTE_BIT32(4)
-#define PCIE_DESC_TX_VLAN               RTE_BIT32(3)
-#define PCIE_DESC_TX_LSO                RTE_BIT32(2)
-#define PCIE_DESC_TX_ENCAP              RTE_BIT32(1)
-#define PCIE_DESC_TX_O_IP4_CSUM         RTE_BIT32(0)
+#define NFD3_DESC_TX_CSUM               RTE_BIT32(7)
+#define NFD3_DESC_TX_IP4_CSUM           RTE_BIT32(6)
+#define NFD3_DESC_TX_TCP_CSUM           RTE_BIT32(5)
+#define NFD3_DESC_TX_UDP_CSUM           RTE_BIT32(4)
+#define NFD3_DESC_TX_VLAN               RTE_BIT32(3)
+#define NFD3_DESC_TX_LSO                RTE_BIT32(2)
+#define NFD3_DESC_TX_ENCAP              RTE_BIT32(1)
+#define NFD3_DESC_TX_O_IP4_CSUM         RTE_BIT32(0)
 
 #define NFD3_TX_DESC_PER_PKT     1
 
@@ -33,7 +33,7 @@ struct nfp_net_nfd3_tx_desc {
 
 			uint16_t mss;         /* MSS to be used for LSO */
 			uint8_t lso_hdrlen;   /* LSO, where the data starts */
-			uint8_t flags;        /* TX Flags, see @PCIE_DESC_TX_* */
+			uint8_t flags;        /* TX Flags, see @NFD3_DESC_TX_* */
 
 			union {
 				struct {
@@ -99,7 +99,7 @@ nfp_net_nfd3_tx_tso(struct nfp_net_txq *txq,
 	}
 
 	txd->mss = rte_cpu_to_le_16(mb->tso_segsz);
-	txd->flags = PCIE_DESC_TX_LSO;
+	txd->flags = NFD3_DESC_TX_LSO;
 
 	return;
 
@@ -127,26 +127,26 @@ nfp_net_nfd3_tx_cksum(struct nfp_net_txq *txq,
 
 	/* Set TCP csum offload if TSO enabled. */
 	if ((ol_flags & RTE_MBUF_F_TX_TCP_SEG) != 0)
-		txd->flags |= PCIE_DESC_TX_TCP_CSUM;
+		txd->flags |= NFD3_DESC_TX_TCP_CSUM;
 
 	/* IPv6 does not need checksum */
 	if ((ol_flags & RTE_MBUF_F_TX_IP_CKSUM) != 0)
-		txd->flags |= PCIE_DESC_TX_IP4_CSUM;
+		txd->flags |= NFD3_DESC_TX_IP4_CSUM;
 
 	if ((ol_flags & RTE_MBUF_F_TX_TUNNEL_MASK) != 0)
-		txd->flags |= PCIE_DESC_TX_ENCAP;
+		txd->flags |= NFD3_DESC_TX_ENCAP;
 
 	switch (ol_flags & RTE_MBUF_F_TX_L4_MASK) {
 	case RTE_MBUF_F_TX_UDP_CKSUM:
-		txd->flags |= PCIE_DESC_TX_UDP_CSUM;
+		txd->flags |= NFD3_DESC_TX_UDP_CSUM;
 		break;
 	case RTE_MBUF_F_TX_TCP_CKSUM:
-		txd->flags |= PCIE_DESC_TX_TCP_CSUM;
+		txd->flags |= NFD3_DESC_TX_TCP_CSUM;
 		break;
 	}
 
 	if ((ol_flags & (RTE_MBUF_F_TX_IP_CKSUM | RTE_MBUF_F_TX_L4_MASK)) != 0)
-		txd->flags |= PCIE_DESC_TX_CSUM;
+		txd->flags |= NFD3_DESC_TX_CSUM;
 }
 
 uint16_t nfp_net_nfd3_xmit_pkts(void *tx_queue,